@@ -47,17 +47,17 @@ class Wrapit():
             if args[0].screenshot == 'all':
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
                 args[0].screenshot_counter += 1
-                screenshot = args[0].get_screenshot_as_png()
-                args[0].save_screenshot(screenshot_name)
-                pytest.config.pluginmanager.get_plugin("html").attach(name="Screenshot", contents=screenshot,
+                screenshot = args[0].save_screenshot(screenshot_name)
+                # args[0].save_screenshot(screenshot_name)
+                pytest.config.pluginmanager.get_plugin("html").attach(name=screenshot_name, contents=screenshot,
                                                                       extension=".png")
 
             elif args[0].screenshot == 'failonly' and result is False:
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
                 args[0].screenshot_counter += 1
-                screenshot = args[0].get_screenshot_as_png()
-                args[0].save_screenshot(screenshot_name)
-                pytest.config.pluginmanager.get_plugin("html").attach(name="Screenshot", contents=screenshot,
+                screenshot = args[0].save_screenshot(screenshot_name)
+                # args[0].save_screenshot(screenshot_name)
+                pytest.config.pluginmanager.get_plugin("html").attach(name=screenshot_name, contents=screenshot,
                                                                       extension=".png")
 
             return result
